Wardy's Untappd Distinct Venues | Untappd
Author: The Untappd Team
Description: Untappd is a new mobile web app that allows you to socially share the brew you're currently enjoying, as well as where you're enjoying it, with your friends!
Keywords: Untappd is a new mobile web app that allows you to socially share the brew you're currently enjoying, as well as where you're enjoying it, with your friends!

### Venue History

4 Pines Brewpub

Dining and Drinking (Brewery)

29/43-45 East Esplanade Manly, NSW

First Visit: 01/12/11

Last Visit: 03/01/25

Check-ins: 1114

Kicks Brewing Verified

Dining and Drinking (Brewery)

31 Shepherd St Marrickville, NSW

Last Visit: 03/01/25

Check-ins: 1

Bracket Brewing

Dining and Drinking (Brewery)

2/48 Addison Road Marrickville, NSW

Last Visit: 03/01/25

Check-ins: 3

Hotel Sweeneys Verified

Dining and Drinking (Bar)

236 Clarence St Sydney, NSW

First Visit: 10/14/11

Last Visit: 03/01/25

Check-ins: 2715

New Brighton Hotel

Dining and Drinking (Pub)

71 The Corso Manly, NSW

First Visit: 02/11/12

Last Visit: 02/28/25

Check-ins: 53

The Taproom

Dining and Drinking (Beer Bar)

71 The Corso Manly, NSW

First Visit: 02/21/24

Last Visit: 02/28/25

Check-ins: 65

Jb & Sons

Dining and Drinking (Burger Joint)

49 Sydney Rd Manly, NSW

First Visit: 02/04/25

Last Visit: 02/28/25

Check-ins: 8

Grain Store Newcastle Verified

Unknown (Beer Bar)

64-66 Scott St Newcastle East, NSW

First Visit: 03/13/22

Last Visit: 02/27/25

Check-ins: 17

The Blind Monk

Dining and Drinking (Bar)

76 Beaumont St Hamilton, NSW

Last Visit: 02/27/25

Check-ins: 1

Good Folk Brewing Co

Dining and Drinking (Brewery)

78 Beaumont Street Hamilton, NSW

Last Visit: 02/27/25

Check-ins: 1

Method Brewing

Dining and Drinking (Brewery)

18 Maitland Rd Islington, NSW

First Visit: 01/20/24

Last Visit: 02/27/25

Check-ins: 8

Thirsty Messiah Brewery

Dining and Drinking (Brewery)

140 Lambton Road Broadmeadow, NSW

Last Visit: 02/27/25

Check-ins: 2

Harbord Bowling and Recreation Club

Sports and Recreation (Sports Club)

Bennett St Curl Curl, NSW

Last Visit: 02/26/25

Check-ins: 2

Untappd at Home Verified

Unknown (Home (private))

NC

First Visit: 03/26/20

Last Visit: 02/24/25

Check-ins: 686

4 Pines Truckbar

Dining and Drinking (Brewery)

9-13 Winbourne Rd Brookvale, NSW

First Visit: 06/17/16

Last Visit: 02/23/25

Check-ins: 103

Dad & Dave's Brewing Verified

Dining and Drinking (Brewery)

45 Mitchell Rd Brookvale, NSW

First Visit: 11/04/17

Last Visit: 02/23/25

Check-ins: 102

Bopp & Tone

Dining and Drinking (Restaurant)

60 Carrington St Sydney, NSW

Last Visit: 02/22/25

Check-ins: 1

The Edinburgh Castle

Dining and Drinking (Pub)

294 Pitt St Sydney, NSW

First Visit: 10/28/11

Last Visit: 02/22/25

Check-ins: 15

Chamberlain Hotel

Dining and Drinking (Pub)

428 Pitt St Sydney, NSW

Last Visit: 02/22/25

Check-ins: 1

The Australian Heritage Hotel

Dining and Drinking (Pub)

100 Cumberland St The Rocks, NSW

First Visit: 01/24/13

Last Visit: 02/22/25

Check-ins: 62

The Fernery Mosman

Dining and Drinking (Australian Restaurant)

719 Military Rd Mosman, NSW

First Visit: 12/01/18

Last Visit: 02/21/25

Check-ins: 7

The Occidental Hotel

Dining and Drinking (Bar)

43 York St Sydney, NSW

First Visit: 05/27/11

Last Visit: 02/20/25

Check-ins: 116

Wynyard Hotel

Travel and Transportation (Hotel)

107 Clarence St Sydney, NSW

First Visit: 01/28/11

Last Visit: 02/20/25

Check-ins: 245

The Office Hotel

Dining and Drinking (Dive Bar)

Kent St. Sydney, NSW

First Visit: 02/18/11

Last Visit: 02/20/25

Check-ins: 40

Tiny’s Sandwich Bar

Dining and Drinking (Sandwich Place)

1/55 Clarence St Sydney, NSW

Last Visit: 02/20/25

Check-ins: 2

Show More